
Changelog
=========

1.1.0
----------

**Added**

* Prepared github actions for continuous integration
* Added compas plugin for automatic Rhino install

**Changed**

**Fixed**

**Deprecated**

**Removed**

1.0.0
-------

* Initial version
